aboutsummaryrefslogtreecommitdiff
path: root/odb/relational/source.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'odb/relational/source.hxx')
-rw-r--r--odb/relational/source.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/odb/relational/source.hxx b/odb/relational/source.hxx
index 53034ac..56949d6 100644
--- a/odb/relational/source.hxx
+++ b/odb/relational/source.hxx
@@ -5066,7 +5066,7 @@ namespace relational
// that the user-provided expression handles this.
//
bool cast (
- call_ == load_call && ma.direct () && const_type (m->type ()));
+ call_ == load_call && ma.direct () && const_member (*m));
if (cast)
obj_prefix_ = "const_cast< " + member_ref_type (*m, false) +
" > (\n";
@@ -5090,7 +5090,7 @@ namespace relational
semantics::names* hint;
semantics::type& t (utype (*m, hint));
// Because we cannot have nested containers, m.type () should
// be the same as w.
//
assert (&t == w);
@@ -5211,7 +5211,7 @@ namespace relational
// that the user-provided expression handles this.
//
bool cast (
- call_ == load_call && ma.direct () && const_type (m.type ()));
+ call_ == load_call && ma.direct () && const_member (m));
if (cast)
os << "const_cast< " << member_ref_type (m, false) <<
" > (" << endl;
@@ -6353,7 +6353,7 @@ namespace relational
// access, then cast away constness. Otherwise, we assume
// that the user-provided expression handles this.
//
- bool cast (ma_set.direct () && const_type (opt->type ()));
+ bool cast (ma_set.direct () && const_member (*opt));
if (cast)
os << "const_cast< version_type& > (" << endl;
@@ -5090,7 +5090,7 @@ namespace relational
semantics::names* hint;
semantics::type& t (utype (*m, hint));
- // Because we cannot have nested containers, m.type () should
+ // Because we cannot have nested containers, member type should
// be the same as w.
//